ConjuredField enum
- Inheritance
- Available extensions
Values
- identity → const ConjuredField
- title → const ConjuredField
- subtitle → const ConjuredField
- color → const ConjuredField
- progress → const ConjuredField
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Type
-
Available on ConjuredField, provided by the XConjuredField extension
no setter
Methods
-
getValue<
T extends Conjured> (T conjured) → Comparable? -
Available on ConjuredField, provided by the XConjuredField extension
-
isPresent<
T extends Conjured> () → bool -
Available on ConjuredField, provided by the XConjuredField extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ConjuredField> - A constant List of the values in this enum, in order of their declaration.