DataHolder<T> class abstract

An interface that holds forwardable data.

Constructors

DataHolder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findData(BuildContext context, Type type) → T?
Finds the data of the type from the context.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(ForwardableDataState<T> receiver) → void
Registers a receiver that provides the data.
toString() String
A string representation of this object.
inherited
unregister(ForwardableDataState<T> receiver) → void
Unregisters a receiver that provides the data.

Operators

operator ==(Object other) bool
The equality operator.
inherited