MapChangeDetails<K, V> class

A map change details containing the added and removed entries.

Constructors

MapChangeDetails(Iterable<MapEntry<K, V>> added, Iterable<MapEntry<K, V>> removed)
Creates a map change details.
const

Properties

added → Iterable<MapEntry<K, V>>
The added entries.
final
hashCode → int
The hash code for this object.
no setterinherited
removed → Iterable<MapEntry<K, V>>
The removed entries.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited