MapNotifier<K, V> class

A map that can be listened to for changes and notifies listeners when the map changes.

Inheritance
Implemented types
Mixed-in types
Available extensions

Constructors

MapNotifier([Map<K, V> map = const {}])
Creates a map notifier.

Properties

entries Iterable<MapEntry<K, V>>
The map entries of this Map.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether the object has listeners.
no setterinherited
isEmpty bool
Whether there is no key/value pair in the map.
no setteroverride
isNotEmpty bool
Whether there is at least one key/value pair in the map.
no setteroverride
keys Iterable<K>
The keys of this Map.
no setteroverride
length int
The number of key/value pairs in the map.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Map<K, V>
The current value of the object. When the value changes, the callbacks registered with addListener will be invoked.
no setteroverride
values Iterable<V>
The values of this Map.
no setteroverride

Methods

addAll(Map<K, V> other) → void
Adds all key/value pairs of other to this map.
override
addChangeListener(MapChangeListener<K, V> listener) → void
Adds a listener to be notified of changes.
override
addEntries(Iterable<MapEntry<K, V>> newEntries) → void
Adds all key/value pairs of newEntries to this map.
override
addListener(VoidCallback listener) → void
Register a closure to be called when the object notifies its listeners.
override
cast<RK, RV>() Map<RK, RV>
Provides a view of this map as having RK keys and RV instances, if necessary.
override
clear() → void
Removes all entries from the map.
override
compute(K key, V compute(K key, V? value)) → V

Available on Map<K, V>, provided by the TMap extension

computeAsync(K key, Future<V> compute(K key, V? value)) Future<V>

Available on Map<K, V>, provided by the TMap extension

computeIfAbsent(K key, V ifAbsent(K key)) → V

Available on Map<K, V>, provided by the TMap extension

computeIfAbsentAsync(K key, Future<V> ifAbsent(K key)) Future<V>

Available on Map<K, V>, provided by the TMap extension

computeIfPresent(K key, V ifPresent(K key, V value)) → V

Available on Map<K, V>, provided by the TMap extension

computeIfPresentAsync(K key, Future<V> ifPresent(K key, V value)) Future<V>

Available on Map<K, V>, provided by the TMap extension

containsKey(Object? key) bool
Whether this map contains the given key.
override
containsValue(Object? value) bool
Whether this map contains the given value.
override
defaultAddListener(ChangeListener listener) → void
Add a listener to the list of listeners.
inherited
defaultNotifyListeners(Object? event) → void
Notify all the listeners.
inherited
defaultRemoveListener(ChangeListener listener) → void
Remove a listener from the list of listeners.
inherited
dispose() → void
Disposes the object making it unusable for further operations and releasing the resources.
inherited
firstKeyWhere(bool test(V)) → K?

Available on Map<K, V>, provided by the TMap extension

firstValueWhere(bool test(K)) → V?

Available on Map<K, V>, provided by the TMap extension

flip() Map<V, List<K>>

Available on Map<K, V>, provided by the TMap extension

flipFlat() Map<V, K>

Available on Map<K, V>, provided by the TMap extension

forEach(void action(K key, V value)) → void
Applies action to each key/value pair of the map.
override
keysWhere(bool test(V)) Iterable<K>

Available on Map<K, V>, provided by the TMap extension

map<K2, V2>(MapEntry<K2, V2> convert(K key, V value)) Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
override
merge(Map<K, V> other) Map<K, V>

Available on Map<K, V>, provided by the TMap extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners(MapChangeDetails<K, V> details) → void
Notifies listeners of the changes.
putIfAbsent(K key, V ifAbsent()) → V
Look up the value of key, or add a new entry if it isn't there.
override
remap((K, V)? remapper(MapEntry<K, V>)) Map<K, V>

Available on Map<K, V>, provided by the TMap extension

remove(Object? key) → V?
Removes key and its associated value, if present, from the map.
override
removeChangeListener(MapChangeListener<K, V> listener) → void
Removes a listener from being notified of changes.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
override
removeWhere(bool test(K key, V value)) → void
Removes all entries of this map that satisfy the given test.
override
sortedKeysByValue(int compare(V, V)?) List<K>

Available on Map<K, V>, provided by the TMap extension

sortedValuesByKey(int compare(K, K)?) List<V>

Available on Map<K, V>, provided by the TMap extension

toString() String
A string representation of this object.
override
update(K key, V update(V value), {V ifAbsent()?}) → V
Updates the value for the provided key.
override
updateAll(V update(K key, V value)) → void
Updates all values.
override
valuesWhere(bool test(K)) Iterable<V>

Available on Map<K, V>, provided by the TMap extension

where(bool test(K key, V value)) Map<K, V>

Available on Map<K, V>, provided by the TMap extension

Operators

operator +(Map<K, V> other) Map<K, V>

Available on Map<K, V>, provided by the TMap extension

operator -(K k) Map<K, V>

Available on Map<K, V>, provided by the TMap extension

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) → V?
The value for the given key, or null if key is not in the map.
override
operator []=(K key, V value) → void
Associates the key with the given value.
override