MetaSEO class abstract
Make it as interface to implement later on only Web platform
Constructors
- MetaSEO()
-
Check the platform if is web so get the correct code
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
Definition of
authormeta tag attribute https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#adding_an_author_and_description Add web mata data ofauthorattribute -
charset(
{required String charset}) → dynamic -
Definition of
charsetmeta tag attribute https://developer.mozilla.org/en-US/docs/Web/HTML/Element/meta#attr-charset Add web mata data ofcharsetattribute -
config(
) → dynamic -
Add web seo mata config method which remove any javascript
code with the same id
metaSEOScriptsand replace if exists with needed one before the end of the body of the html web file automatically. This method should be run before any meta seo method to run the package correctly -
description(
{required String description}) → dynamic -
Definition of
descriptionmeta tag attribute https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#adding_an_author_and_description Add web mata data ofdescriptionattribute -
facebookAppID(
{required String facebookAppID}) → dynamic -
Definition of
fb:app_idmeta tag attribute https://ogp.me https://developers.facebook.com/docs/sharing/webmasters/ Add web mata data offacebookAppIDattribute -
httpEquiv(
{required String httpEquiv}) → dynamic -
Definition of
http-equivmeta tag attribute https://developer.mozilla.org/en-US/docs/Web/HTML/Element/meta#attr-http-equiv Add web mata data ofhttpEquivattribute -
keyValue(
{required String key, required String value}) → dynamic -
Definition of
keymeta tag attribute If you do not found meta key you want just use metaKey Definition ofvaluemeta tag attribute The value is used for other key-value meta not listed in attributes by metaValue Add web mata data of other meta key with value -
keywords(
{required String keywords}) → dynamic -
Definition of
keywordsmeta tag attribute Separate list of keyword strings by commas Add web mata data ofkeywordsattribute -
nameContent(
{required String name, required String content}) → dynamic -
Definition of
namemeta tag attribute If you do not found meta name you want just use metaName Definition ofcontentmeta tag attribute The value is used for other named meta not listed in attributes by metaNameContent Add web mata data of other meta named with content -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
ogDescription(
{required String ogDescription}) → dynamic -
Definition of
og:descriptionmeta tag attribute https://ogp.me https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#other_types_of_metadata Add web mata data ofogDescriptionattribute -
ogImage(
{required String ogImage}) → dynamic -
Definition of
og:imagemeta tag attribute https://ogp.me https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#other_types_of_metadata Add web mata data ofogImageattribute -
ogTitle(
{required String ogTitle}) → dynamic -
Definition of
og:titlemeta tag attribute https://ogp.me https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#other_types_of_metadata Add web mata data ofogTitleattribute -
propertyContent(
{required String property, required String content}) → dynamic -
Definition of
propertymeta tag attribute If you do not found meta property you want just use metaProperty Definition ofcontentmeta tag attribute The value is used for other property meta not listed in attributes by metaPropertyContent Add web mata data of other meta property with content -
robots(
{required RobotsName robotsName, required String content}) → dynamic -
Definition of
robotsNamemeta tag attribute Definition ofcontentmeta tag attribute https://developers.google.com/search/docs/crawling-indexing/robots-meta-tag Add web mata data ofrobotsNameattribute Add web mata data ofcontentattribute -
toString(
) → String -
A string representation of this object.
inherited
-
twitterCard(
{required TwitterCard twitterCard}) → dynamic -
Definition of
twitter:cardmeta tag attribute https://developer.twitter.com/en/docs/twitter-for-websites/cards/guides/getting-started Add web mata data oftwitterCardattribute -
twitterDescription(
{required String twitterDescription}) → dynamic -
Definition of
twitter:descriptionmeta tag attribute https://developer.twitter.com/en/docs/twitter-for-websites/cards/overview/markup Add web mata data oftwitterDescriptionattribute -
twitterImage(
{required String twitterImage}) → dynamic -
Definition of
twitter:imagemeta tag attribute https://developer.twitter.com/en/docs/twitter-for-websites/cards/overview/markup Add web mata data oftwitterImageattribute -
twitterTitle(
{required String twitterTitle}) → dynamic -
Definition of
twitter:titlemeta tag attribute https://developer.twitter.com/en/docs/twitter-for-websites/cards/overview/markup Add web mata data oftwitterTitleattribute -
viewport(
{required String viewport}) → dynamic -
Definition of
viewportmeta tag attribute Separate list of viewport strings by commas https://developer.mozilla.org/en-US/docs/Web/HTML/Viewport_meta_tag Add web mata data ofviewportattribute
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited