ModelProperty<T> mixin

A mixin for all kinds of Model properties.

Implemented types

Properties

dataKey → Symbol
The data key of the model.
no setter
dataType → Type
The data type of the model.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isReadOnly → bool
Whether the model is read-only.
no setter
modelKey → ModelKey<T>
The model key of the model.
no setter
normalized → Model<T>
The normalized model of the model.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
The data value of the model.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited