change<T> static method

void change<T>(
  1. BuildContext context,
  2. Symbol key,
  3. T data
)

Change the data of the model with the given key. Throws an assertion error if the model is read-only.

  • T The type of the data.
  • context The build context.
  • key The data key.
  • data The new data.

Implementation

static void change<T>(BuildContext context, Symbol key, T data) {
  final property = findProperty<T>(context, key);
  property.value = data;
}