PylonBuilder typedef

PylonBuilder = Widget Function(BuildContext context)

A typedef for a function that builds a widget given a BuildContext.

This is used throughout the Pylon package for builder functions that create widgets with access to pylon values from the provided context.

Implementation

typedef PylonBuilder = Widget Function(BuildContext context);