SetListenable<T> class
abstract
A set that can be listened to for changes.
- Inheritance
-
- Object
- Listenable
- ValueListenable<
Set< T> > - SetListenable
Constructors
Properties
Methods
-
addChangeListener(
SetChangeListener< T> listener) → void -
Adds a
listenerto be notified of changes. -
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeChangeListener(
SetChangeListener< T> listener) → void -
Removes a
listenerfrom being notified of changes. -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited