SetNotifier<T> class

A set notifier class that allows mutable updates and notifies listeners of changes.

Inheritance
Implemented types
Mixed-in types
Available extensions

Constructors

SetNotifier([Set<T> set = const {}])
Constructs a SetNotifier with an initial set.

Properties

ascending → List<int>

Available on Iterable<int>, provided by the TIterableInt extension

no setter
ascending → List<double>

Available on Iterable<double>, provided by the TIterableDouble extension

no setter
descending → List<int>

Available on Iterable<int>, provided by the TIterableInt extension

no setter
descending → List<double>

Available on Iterable<double>, provided by the TIterableDouble extension

no setter
disabled → bool

Available on Set<WidgetState>, provided by the WidgetStateExtension extension

no setter
error → bool

Available on Set<WidgetState>, provided by the WidgetStateExtension extension

no setter
evens → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

no setter
first → T
The first element.
no setterinherited
firstOr → T?

Available on Iterable<T>, provided by the TIterable extension

no setter
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
focused → bool

Available on Set<WidgetState>, provided by the WidgetStateExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether the object has listeners.
no setterinherited
hovered → bool

Available on Set<WidgetState>, provided by the WidgetStateExtension extension

no setter
indexed → Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<T>
An iterator that iterates over the elements of this set.
no setteroverride
last → T
The last element.
no setterinherited
lastIndex → int

Available on Iterable<T>, provided by the TIterable extension

Returns the last index of the iterable.
no setter
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length → int
The number of elements in this Iterable.
no setteroverride
list → List<T>

Available on Iterable<T>, provided by the TIterable extension

no setter
middleIndex → int

Available on Iterable<T>, provided by the TIterable extension

Returns the middle index of the iterable.
no setter
mostCommon → T?

Available on Iterable<T>, provided by the TIterable extension

no setter
nonNulls → Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
notNull → Iterable<T>

Available on Iterable<T>, provided by the TIterable extension

no setter
odds → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

no setter
pressed → bool

Available on Set<WidgetState>, provided by the WidgetStateExtension extension

no setter
primes → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool

Available on Set<WidgetState>, provided by the WidgetStateExtension extension

no setter
set → Set<T>

Available on Iterable<T>, provided by the TIterable extension

no setter
single → T
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
toJSIterable → JSIterable<T>

Available on Iterable<T>, provided by the IterableToJSIterable extension

A JSIterable wrapper that proxies to the Dart iterable API.
no setter
unique → Iterable<T>

Available on Iterable<T>, provided by the TIterable extension

no setter
value → Set<T>
The current value of the object.
no setteroverride
wait → Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(T value) → bool
Adds value to the set.
override
add(T element) → Iterable<T>

Available on Iterable<T>, provided by the TIterable extension

addAll(Iterable<T> values) → void
Adds all elements to this set.
override
addAll(Iterable<T> elements) → Iterable<T>

Available on Iterable<T>, provided by the TIterable extension

addAllFirst(Iterable<T> elements) → Iterable<T>

Available on Iterable<T>, provided by the TIterable extension

addChangeListener(SetChangeListener<T> listener) → void
Adds a listener to be notified of changes.
override
addFirst(T element) → Iterable<T>

Available on Iterable<T>, provided by the TIterable extension

addListener(VoidCallback listener) → void
Register a closure to be called when the object notifies its listeners.
override
any(bool test(T value)) → bool
Checks whether any element of this iterable satisfies test.
inherited
asKeys<R>(R f(T)) → Map<T, R>

Available on Iterable<T>, provided by the TIterable extension

Returns a new Map where the values are used as keys in a map.
asNameMap() → Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
asValues<R>(R f(T)) → Map<R, T>

Available on Iterable<T>, provided by the TIterable extension

Returns a new Map where the values are used as values in a map.
average() → double

Available on Iterable<int>, provided by the TIterableInt extension

average() → double

Available on Iterable<double>, provided by the TIterableDouble extension

averageInt() → int

Available on Iterable<int>, provided by the TIterableInt extension

byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
cast<R>() → Set<R>
Provides a view of this set as a set of R instances.
override
chunked(int chunkSize) → Iterable<List<T>>

Available on Iterable<T>, provided by the TIterable extension

clear() → void
Removes all elements from the set.
override
column({Key? key, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, MainAxisSize mainAxisSize = MainAxisSize.max, VerticalDirection verticalDirection = VerticalDirection.down, TextBaseline textBaseline = TextBaseline.alphabetic, TextDirection textDirection = TextDirection.ltr}) → Widget

Available on Iterable<Widget>, provided by the XIterableWidget extension

contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
containsAll(Iterable<Object?> other) → bool
Whether this set contains all the elements of other.
override
deduplicated() → Iterable<T>

Available on Iterable<T>, provided by the TIterable extension

Returns a new Iterable with deduplicated elements.
deduplicatedList() → List<T>

Available on Iterable<T>, provided by the TIterable extension

Returns a new List with deduplicated elements.
defaultAddListener(ChangeListener listener) → void
Add a listener to the list of listeners.
inherited
defaultNotifyListeners(Object? event) → void
Notify all the listeners.
inherited
defaultRemoveListener(ChangeListener listener) → void
Remove a listener from the list of listeners.
inherited
diff(Iterable<T> other) → Iterable<T>

Available on Iterable<T>, provided by the TIterable extension

difference(Set<Object?> other) → Set<T>
Creates a new set with the elements of this that are not in other.
override
dispose() → void
Disposes the object making it unusable for further operations and releasing the resources.
inherited
elementAt(int index) → T
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
every(bool test(T value)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(T element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(T value), {T orElse()?}) → T
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, T element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<T> other) → Iterable<T>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(T element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
groupBy<M>(M grouper(T)) → Map<M, List<T>>

Available on Iterable<T>, provided by the TIterable extension

intersection(Set<Object?> other) → Set<T>
Creates a new set which is the intersection between this set and other.
override
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
joinSeparator(T separator) → Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

lastWhere(bool test(T value), {T orElse()?}) → T
The last element that satisfies the given predicate test.
inherited
lookup(Object? object) → T?
If an object equal to object is in the set, return it.
override
map<T>(T toElement(T e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
mapIndexed<V>(V f(T value, int index)) → Iterable<V>

Available on Iterable<T>, provided by the TIterable extension

mapList<R>(R f(T)) → List<R>

Available on Iterable<T>, provided by the TIterable extension

Returns a new List with mapped elements.
max() → double

Available on Iterable<double>, provided by the TIterableDouble extension

max() → int

Available on Iterable<int>, provided by the TIterableInt extension

median() → int

Available on Iterable<int>, provided by the TIterableInt extension

median() → double

Available on Iterable<double>, provided by the TIterableDouble extension

middleValue() → T?

Available on Iterable<T>, provided by the TIterable extension

Returns the middle element of the iterable.
min() → int

Available on Iterable<int>, provided by the TIterableInt extension

min() → double

Available on Iterable<double>, provided by the TIterableDouble extension

mode() → int

Available on Iterable<int>, provided by the TIterableInt extension

mode() → double

Available on Iterable<double>, provided by the TIterableDouble extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners(SetChangeDetails<T> details) → void
Notifies listeners of changes.
occurrences() → Map<T, int>

Available on Iterable<T>, provided by the TIterable extension

Returns a new Map with the number of occurrences of each element.
product() → int

Available on Iterable<int>, provided by the TIterableInt extension

product() → double

Available on Iterable<double>, provided by the TIterableDouble extension

reduce(T combine(T value, T element)) → T
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
reduceOr(T or, T combine(T, T)) → T

Available on Iterable<T>, provided by the TIterable extension

remove(Object? value) → bool
Removes value from the set.
override
removeAll(Iterable<Object?> elements) → void
Removes each element of elements from this set.
override
removeChangeListener(SetChangeListener<T> listener) → void
Removes a listener from being notified of changes.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
override
removeWhere(bool test(T value)) → void
Removes all elements of this set that satisfy test.
override
retainAll(Iterable<Object?> elements) → void
Removes all elements of this set that are not elements in elements.
override
retainWhere(bool test(T value)) → void
Removes all elements of this set that fail to satisfy test.
override
reversed() → Iterable<T>

Available on Iterable<T>, provided by the TIterable extension

Returns a new Iterable with reversed elements.
reversedList() → List<T>

Available on Iterable<T>, provided by the TIterable extension

Returns a new List with reversed elements.
row({Key? key, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, MainAxisSize mainAxisSize = MainAxisSize.max, VerticalDirection verticalDirection = VerticalDirection.down, TextBaseline textBaseline = TextBaseline.alphabetic, TextDirection textDirection = TextDirection.ltr}) → Widget

Available on Iterable<Widget>, provided by the XIterableWidget extension

select(bool test(T)) → T?

Available on Iterable<T>, provided by the TIterable extension

selectLast(bool test(T)) → T?

Available on Iterable<T>, provided by the TIterable extension

shuffled() → Iterable<T>

Available on Iterable<T>, provided by the TIterable extension

Returns a new Iterable with shuffled elements.
shuffledList() → List<T>

Available on Iterable<T>, provided by the TIterable extension

Returns a new List with shuffled elements.
singleWhere(bool test(T value), {T orElse()?}) → T
The single element that satisfies test.
inherited
skip(int n) → Iterable<T>

Available on Iterable<T>, provided by the TIterable extension

skip(int count) → Iterable<T>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(T value)) → Iterable<T>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
softMap<R>(R? f(T)) → Iterable<R>

Available on Iterable<T>, provided by the TIterable extension

Returns a new Iterable with mapped elements that are not null.
softMapList<R>(R? f(T)) → List<R>

Available on Iterable<T>, provided by the TIterable extension

Returns a new List with mapped elements that are not null.
sorted([int compare(T, T)?]) → List<T>

Available on Iterable<T>, provided by the TIterable extension

Returns a new List with sorted elements.
stack({Key? key, AlignmentGeometry alignment = AlignmentDirectional.topStart, TextDirection textDirection = TextDirection.ltr, StackFit fit = StackFit.loose, Clip clipBehavior = Clip.hardEdge}) → Widget

Available on Iterable<Widget>, provided by the XIterableWidget extension

sum() → double

Available on Iterable<double>, provided by the TIterableDouble extension

sum() → int

Available on Iterable<int>, provided by the TIterableInt extension

take(int count) → Iterable<T>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(T value)) → Iterable<T>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<T>
Creates a List containing the elements of this Iterable.
inherited
toRect() → Rect

Available on Iterable<Offset>, provided by the XIterableOffset extension

toRect() → Rect

Available on Iterable<Rect>, provided by the XIterableRect extension

toSet() → Set<T>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
A string representation of this object.
override
union(Set<T> other) → Set<T>
Creates a new set which contains all the elements of this set and other.
override
wait() → Future<List<T>>

Available on Iterable<Future<T>>, provided by the TIterableFuture extension

weave(Iterable<T> other) → Iterable<T>

Available on Iterable<T>, provided by the TIterable extension

Weaves two iterables together into a new Iterable alternating elements.
where(bool test(T value)) → Iterable<T>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereIndex(bool test(T value, int index)) → Iterable<T>

Available on Iterable<T>, provided by the TIterable extension

whereType<T>() → Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited
withPylons(PylonBuilder builder) → List<Widget>

Available on Iterable<T>, provided by the XPylonIterable extension

Maps each item in this iterable to a Pylon widget using the provided builder, returning a list suitable for use in widget trees.

Operators

operator %(int value) → Iterable<double>

Available on Iterable<double>, provided by the TIterableDouble extension

operator %(int value) → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

operator &(int value) → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

operator *(int value) → Iterable<double>

Available on Iterable<double>, provided by the TIterableDouble extension

operator *(int value) → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

operator +(int value) → Iterable<double>

Available on Iterable<double>, provided by the TIterableDouble extension

operator +(int value) → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

operator +(T element) → Set<T>

Available on Set<T>, provided by the TSet extension

operator -(int value) → Iterable<double>

Available on Iterable<double>, provided by the TIterableDouble extension

operator -(int value) → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

operator -(T element) → Set<T>

Available on Set<T>, provided by the TSet extension

operator /(int value) → Iterable<double>

Available on Iterable<double>, provided by the TIterableDouble extension

operator <<(int value) → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

operator ==(Object other) → bool
The equality operator.
inherited
operator >>(int value) → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

operator ^(int value) → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

operator unary-() → Iterable<double>

Available on Iterable<double>, provided by the TIterableDouble extension

operator unary-() → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

operator |(int value) → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

operator ~() → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension

operator ~/(int value) → Iterable<int>

Available on Iterable<int>, provided by the TIterableInt extension