AntiFlickerDirection enum

Defines the directions for the anti-flicker gradient used with GlassAntiFlicker.

These directions specify where the gradient should fade from to prevent visual artifacts at the edges of glass panels.

See also:

  • doc/component/glass.md for more detailed documentation
  • GlassAntiFlicker, which uses this enum to create anti-flicker gradients
Inheritance
Available extensions

Values

top → const AntiFlickerDirection

Gradient fades from top to bottom

bottom → const AntiFlickerDirection

Gradient fades from bottom to top

left → const AntiFlickerDirection

Gradient fades from left to right

Gradient fades from right to left

Properties

alignmentDark → Alignment

Available on AntiFlickerDirection, provided by the XAntiFlickerDirection extension

Gets the alignment for the dark end of the gradient.
no setter
alignmentLight → Alignment

Available on AntiFlickerDirection, provided by the XAntiFlickerDirection extension

Gets the alignment for the light end of the gradient.
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
opposite → AntiFlickerDirection

Available on AntiFlickerDirection, provided by the XAntiFlickerDirection extension

Gets the opposite direction.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<AntiFlickerDirection>
A constant List of the values in this enum, in order of their declaration.