GutterTheme class

Constructors

GutterTheme({double gutterCalc(double screenWidth) = _defaultGutterCalc, bool enabled = true})
const

Properties

enabled → bool
final
gutterCalc → double Function(double screenWidth)
The value returned is both applied on the left and right.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double gutterCalc(double screenWidth)?, bool? enabled}) → GutterTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited