ImageStyle class

Constructors

ImageStyle({BoxFit fit = BoxFit.contain, double width = double.infinity, double height = double.infinity, Color? color, BlendMode? colorBlendMode, AlignmentGeometry? alignment})
const

Properties

alignment → AlignmentGeometry?
final
color → Color?
final
colorBlendMode → BlendMode?
final
fit → BoxFit
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited