ActionOption class

Inheritance

Constructors

ActionOption({required String name, required void action(), String? description, IconData icon = Icons.gear_six_fill, bool shouldShow(BuildContext context) = _defShouldShow})
const

Properties

action → void Function()
final
built → Widget
no setteroverride
description → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
finalinherited
id → String
no setterinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldShow → bool Function(BuildContext context)
finalinherited

Methods

matches(String text) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited