DoubleOption class

Inheritance

Constructors

DoubleOption({required String name, double defaultValue = 0.0, String? description, IconData icon = Icons.gear_six_fill, required double? reader(), required void writer(double? t), bool shouldShow(BuildContext context) = _defShouldShow})

Properties

built → Widget
no setteroverride
defaultValue → double
finalinherited
description → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
finalinherited
id → String
no setterinherited
name → String
finalinherited
reader → double? Function()
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldShow → bool Function(BuildContext context)
finalinherited
writer → void Function(double? t)
finalinherited

Methods

matches(String text) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited