Option class abstract

Implementers

Constructors

Option({IconData icon = Icons.gear_six_fill, required String name, String? description, bool shouldShow(BuildContext context) = _defShouldShow})
const

Properties

built → Widget
no setter
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
final
id → String
no setter
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldShow → bool Function(BuildContext context)
final

Methods

matches(String text) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited