OptionField<T> class abstract

Inheritance
Implementers

Constructors

OptionField({required String name, String? description, IconData icon = Icons.gear_six_fill, required T defaultValue, required T? reader(), required void writer(T? t), bool shouldShow(BuildContext context) = _defShouldShow})
const

Properties

built → Widget
no setterinherited
defaultValue → T
final
description → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
finalinherited
id → String
no setterinherited
name → String
finalinherited
reader → T? Function()
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldShow → bool Function(BuildContext context)
finalinherited
writer → void Function(T? t)
final

Methods

matches(String text) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited