OptionScreen class

Inheritance

Constructors

OptionScreen({required String name, String? description, IconData icon = Icons.gear_six_fill, List<Option> options = const [], bool shouldShow(BuildContext context) = _defShouldShow})

Properties

built → Widget
no setteroverride
description → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
finalinherited
id → String
no setterinherited
name → String
finalinherited
options → List<Option>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldShow → bool Function(BuildContext context)
finalinherited

Methods

getFields() → Iterable<OptionField>
inherited
getNonGroups() → Iterable<Option>
inherited
getParent(Option root) → Option?
inherited
matches(String text) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited