StringOption class

Inheritance

Constructors

StringOption({required String name, String defaultValue = "", String? description, IconData icon = Icons.gear_six_fill, required String? reader(), required void writer(String? t), bool shouldShow(BuildContext context) = _defShouldShow})

Properties

built → Widget
no setteroverride
defaultValue → String
finalinherited
description → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
finalinherited
id → String
no setterinherited
name → String
finalinherited
reader → String? Function()
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldShow → bool Function(BuildContext context)
finalinherited
writer → void Function(String? t)
finalinherited

Methods

matches(String text) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited