onLongSecondaryPressed method
Widget
onLongSecondaryPressed(
- VoidCallback action, {
- HitTestBehavior? behavior,
- Set<
PointerDeviceKind> ? supportedDevices,
Adds a handler for long press gestures with the secondary button to this widget in Arcane UI.
For advanced context on long right-click in CardSection. action post-hold, with options.
Integrates ArcaneTheme and accessibility via Semantics.
Implementation
Widget onLongSecondaryPressed(VoidCallback action,
{HitTestBehavior? behavior,
Set<PointerDeviceKind>? supportedDevices}) =>
OnGesture.longSecondaryPress(
action: action,
behavior: behavior,
supportedDevices: supportedDevices,
child: this);