stopping property
Whether to stop glass effects in descendant widgets.
When true, child Glass instances will render without blur unless Glass.ignoreContextSignals is set; defaults to false for normal operation.
Implementation
final bool stopping;
Whether to stop glass effects in descendant widgets.
When true, child Glass instances will render without blur unless Glass.ignoreContextSignals is set; defaults to false for normal operation.
final bool stopping;