TrackerData class

A class that holds data for a tracker.

This class holds a tooltip and a tracker level level.

Constructors

TrackerData({required Widget tooltip, required TrackerLevel level})
Creates a new TrackerData instance. requires two parameters: tooltip is the tooltip for the tracker. level is the tracker level.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
level → TrackerLevel
The tracker level.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tooltip → Widget
The tooltip for the tracker.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited