TrackerLevel class abstract

An abstract class that holds values for different Tracker levels.

This class defines the color and name for each TrackerLevel.

For example TrackerLevel.fine holds two values:

  • name which is set to "Fine"
  • color which is set to Colors.green

Constructors

TrackerLevel()

Properties

color → Color
Gets the color for the specified TrackerLevel.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
Gets the name for the specified TrackerLevel.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

critical → const TrackerLevel
Default values for the critical level.
fine → const TrackerLevel
Default values for the fine level.
unknown → const TrackerLevel
Default values for the unknown level.
warning → const TrackerLevel
Default values for the warning level.