AbstractButtonStyle class abstract

Implementers
Available extensions

Constructors

AbstractButtonStyle()

Properties

decoration → ButtonStateProperty<Decoration>
no setter
hashCode → int
The hash code for this object.
no setterinherited
iconTheme → ButtonStateProperty<IconThemeData>
no setter
margin → ButtonStateProperty<EdgeInsetsGeometry>
no setter
mouseCursor → ButtonStateProperty<MouseCursor>
no setter
padding → ButtonStateProperty<EdgeInsetsGeometry>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → ButtonStateProperty<TextStyle>
no setter

Methods

copyWith({ButtonStatePropertyDelegate<Decoration>? decoration, ButtonStatePropertyDelegate<MouseCursor>? mouseCursor, ButtonStatePropertyDelegate<EdgeInsetsGeometry>? padding, ButtonStatePropertyDelegate<TextStyle>? textStyle, ButtonStatePropertyDelegate<IconThemeData>? iconTheme, ButtonStatePropertyDelegate<EdgeInsetsGeometry>? margin}) → AbstractButtonStyle

Available on AbstractButtonStyle, provided by the ButtonStyleExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited