HoverTheme class

Constructors

HoverTheme({Duration? debounceDuration, HitTestBehavior? hitTestBehavior, Duration? waitDuration, Duration? minDuration, Duration? showDuration})
const

Properties

debounceDuration → Duration?
final
hashCode → int
The hash code for this object.
no setteroverride
hitTestBehavior → HitTestBehavior?
final
minDuration → Duration?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDuration → Duration?
final
waitDuration → Duration?
final

Methods

copyWith({ValueGetter<Duration?>? debounceDuration, ValueGetter<HitTestBehavior?>? hitTestBehavior, ValueGetter<Duration?>? waitDuration, ValueGetter<Duration?>? minDuration, ValueGetter<Duration?>? showDuration}) → HoverTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override