DesktopPointerScrollEvent class

Inheritance

Constructors

DesktopPointerScrollEvent({required Offset position, required int device, required int embedderId, required PointerDeviceKind kind, required Duration timeStamp, required int viewId, required Offset scrollDelta})
const

Properties

buttons → int
Bit field using the *Button constants such as kPrimaryMouseButton, kSecondaryStylusButton, etc.
finalinherited
delta → Offset
Distance in logical pixels that the pointer moved since the last PointerMoveEvent or PointerHoverEvent.
finalinherited
device → int
Unique identifier for the pointing device, reused across interactions.
finalinherited
distance → double
The distance of the detected object from the input surface.
finalinherited
distanceMax → double
The maximum value that distance can return for this pointer.
finalinherited
distanceMin → double
The minimum value that distance can return for this pointer.
no setterinherited
down → bool
Set if the pointer is currently down.
finalinherited
embedderId → int
Unique identifier that ties the PointerEvent to the embedder event that created it.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
kind → PointerDeviceKind
The kind of input device for which the event was generated.
finalinherited
localDelta → Offset
The delta transformed into the event receiver's local coordinate system according to transform.
no setterinherited
localPosition → Offset
The position transformed into the event receiver's local coordinate system according to transform.
no setterinherited
obscured → bool
Set if an application from a different security domain is in any way obscuring this application's window.
finalinherited
orientation → double
The orientation angle of the detected object, in radians.
finalinherited
original → PointerEvent?
The original un-transformed PointerEvent before any transforms were applied.
finalinherited
platformData → int
Opaque platform-specific data associated with the event.
finalinherited
pointer → int
Unique identifier for the pointer, not reused. Changes for each new pointer down event.
finalinherited
position → Offset
Coordinate of the position of the pointer, in logical pixels in the global coordinate space.
finalinherited
pressure → double
The pressure of the touch.
finalinherited
pressureMax → double
The maximum value that pressure can return for this pointer.
finalinherited
pressureMin → double
The minimum value that pressure can return for this pointer.
finalinherited
radiusMajor → double
The radius of the contact ellipse along the major axis, in logical pixels.
finalinherited
radiusMax → double
The maximum value that could be reported for radiusMajor and radiusMinor for this pointer, in logical pixels.
finalinherited
radiusMin → double
The minimum value that could be reported for radiusMajor and radiusMinor for this pointer, in logical pixels.
finalinherited
radiusMinor → double
The radius of the contact ellipse along the minor axis, in logical pixels.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDelta → Offset
The amount to scroll, in logical pixels.
finalinherited
size → double
The area of the screen being pressed.
finalinherited
synthesized → bool
Set if the event was synthesized by Flutter.
finalinherited
tilt → double
The tilt angle of the detected object, in radians.
finalinherited
timeStamp → Duration
Time of event dispatch, relative to an arbitrary timeline.
finalinherited
transform → Matrix4?
The transformation used to transform this event from the global coordinate space into the coordinate space of the event receiver.
finalinherited
viewId → int
The ID of the FlutterView which this event originated from.
finalinherited

Methods

copyWith({int? viewId, Duration? timeStamp, int? pointer, PointerDeviceKind? kind, int? device, Offset? position, Offset? delta, int? buttons, bool? obscured, double? pressure, double? pressureMin, double? pressureMax, double? distance, double? distanceMax, double? size, double? radiusMajor, double? radiusMinor, double? radiusMin, double? radiusMax, double? orientation, double? tilt, bool? synthesized, int? embedderId, RespondPointerEventCallback? onRespond}) → PointerScrollEvent
Creates a copy of event with the specified properties replaced.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
respond({required bool allowPlatformDefault}) → void
Sends a response to the native embedder for the PointerSignalEvent.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringFull() → String
Returns a complete textual description of this event.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
transformed(Matrix4? transform) → PointerScrollEvent
Transforms the event from the global coordinate space into the coordinate space of an event receiver.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited