badgeGap property
Spacing between the avatar and badge in logical pixels.
Type: double?. Controls the gap between the avatar edge and badge edge.
If null, defaults to theme.scaling * 4 pixels.
Implementation
final double? badgeGap;
Spacing between the avatar and badge in logical pixels.
Type: double?. Controls the gap between the avatar edge and badge edge.
If null, defaults to theme.scaling * 4 pixels.
final double? badgeGap;