gap property
Spacing between overlapping avatars in logical pixels.
Controls the gap between the edges of overlapping avatars. If null, defaults to theme.scaling * 4.
Implementation
final double? gap;
Spacing between overlapping avatars in logical pixels.
Controls the gap between the edges of overlapping avatars. If null, defaults to theme.scaling * 4.
final double? gap;