DateStateBuilder typedef

DateStateBuilder = DateState Function(DateTime date)

Callback function type for determining the state of calendar dates.

Takes a DateTime and returns a DateState to control whether that date should be enabled or disabled for user interaction.

Implementation

typedef DateStateBuilder = DateState Function(DateTime date);