CarouselAlignment enum

CarouselAlignment is used to align the carousel items.

Inheritance
Available extensions

Values

start → const CarouselAlignment

Aligns the carousel items to the start.

const CarouselAlignment(0)
center → const CarouselAlignment

Aligns the carousel items to the center.

const CarouselAlignment(0.5)
end → const CarouselAlignment

Aligns the carousel items to the end.

const CarouselAlignment(1)

Properties

alignment → double
The alignment value.
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<CarouselAlignment>
A constant List of the values in this enum, in order of their declaration.