CarouselController class

A controller for the carousel.

Inheritance

Constructors

CarouselController()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldAnimate → bool
Whether the carousel should animate.
no setter
value → double
The current value of the controller.
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object notifies its listeners.
override
animateNext(Duration duration, [Curve curve = Curves.easeInOut]) → void
Animates to the next item.
animatePrevious(Duration duration, [Curve curve = Curves.easeInOut]) → void
Animates to the previous item.
animateSnap(Duration duration, [Curve curve = Curves.easeInOut]) → void
Animates the current value to the nearest integer.
animateTo(double value, Duration duration, [Curve curve = Curves.linear]) → void
Animates to the specified value.
dispose() → void
Disposes the controller.
getCurrentIndex(int? itemCount) → double
Animates to the specified value.
jumpTo(double value) → void
Jumps to the specified value.
next() → void
Jumps to the next item.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previous() → void
Jumps to the previous item.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
override
snap() → void
Snaps the current value to the nearest integer.
tick(Duration delta) → void
Animates to the specified value.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited