ChipTheme class

Theme for Chip.

Constructors

ChipTheme({EdgeInsetsGeometry? padding, AbstractButtonStyle? style})
Creates a ChipTheme.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
padding → EdgeInsetsGeometry?
The padding inside the chip.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → AbstractButtonStyle?
The default Button style of the chip.
final

Methods

copyWith({ValueGetter<EdgeInsetsGeometry?>? padding, ValueGetter<AbstractButtonStyle?>? style}) → ChipTheme
Creates a copy of this theme with the given values replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override