child property
Optional child widget passed to custom builders.
Available only when using NumberTicker.builder. Passed through to the builder function for optimization when part of the display remains constant.
Implementation
final Widget? child;
Optional child widget passed to custom builders.
Available only when using NumberTicker.builder. Passed through to the builder function for optimization when part of the display remains constant.
final Widget? child;