SkeletonTheme constructor

const SkeletonTheme({
  1. Duration? duration,
  2. Color? fromColor,
  3. Color? toColor,
  4. bool? enableSwitchAnimation,
})

Creates a SkeletonTheme.

All parameters are optional and can be null to use intelligent defaults that integrate with the current theme's color scheme and design system.

Example:

const SkeletonTheme(
  duration: Duration(milliseconds: 800),
  fromColor: Colors.grey.withOpacity(0.1),
  toColor: Colors.grey.withOpacity(0.2),
  enableSwitchAnimation: true,
);

Implementation

const SkeletonTheme({
  this.duration,
  this.fromColor,
  this.toColor,
  this.enableSwitchAnimation,
});