CheckboxController class

Inheritance
Mixed-in types

Constructors

CheckboxController(CheckboxState value)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isChecked → bool
no setter
isIndeterminate → bool
no setter
isUnchecked → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ CheckboxState
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
check() → void
dispose() → void
Discards any resources used by the object.
inherited
indeterminate() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toggle() → void
toggleTristate() → void
toString() → String
A string representation of this object.
inherited
uncheck() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited