ControlledComponentData<T> class

Constructors

ControlledComponentData({required T value, required ValueChanged<T> onChanged, required bool enabled})
const

Properties

enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
onChanged → ValueChanged<T>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited