DateTimeRange class

Available extensions

Constructors

DateTimeRange(DateTime start, DateTime end)
const

Properties

end → DateTime
final
fullDay → DateTimeRange

Available on DateTimeRange, provided by the XDateTimeRangeArcane extension

no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → DateTime
final
toLocal → DateTimeRange

Available on DateTimeRange, provided by the XDateTimeRangeArcane extension

no setter
toUtc → DateTimeRange

Available on DateTimeRange, provided by the XDateTimeRangeArcane extension

no setter

Methods

copyWith({ValueGetter<DateTime>? start, ValueGetter<DateTime>? end}) → DateTimeRange
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override