ConditionalValidator<T> class

Inheritance

Constructors

ConditionalValidator(FuturePredicate<T> predicate, {required String message, List<FormKey> dependencies = const []})
const

Properties

dependencies → List<FormKey>
final
hashCode → int
The hash code for this object.
no setteroverride
message → String
final
predicate → FuturePredicate<T>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

combine(Validator<T> other) → Validator<T>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRevalidate(FormKey source) → bool
override
toString() → String
A string representation of this object.
inherited
validate(BuildContext context, T? value, FormValidationMode lifecycle) → FutureOr<ValidationResult?>
override

Operators

operator &(Validator<T> other) → Validator<T>
inherited
operator +(Validator<T> other) → Validator<T>
inherited
operator ==(Object other) → bool
The equality operator.
override
operator unary-() → Validator<T>
inherited
operator |(Validator<T> other) → Validator<T>
inherited
operator ~() → Validator<T>
inherited