WidgetPart class

Inheritance

Constructors

WidgetPart(Widget widget)
const

Properties

canHaveValue → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
part → InputPart
no setterinherited
partKey → Object?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
no setterinherited
widget → Widget
final

Methods

build(BuildContext context, FormattedInputData data) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withValue(String value) → FormattedValuePart
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited