TextInputFormatters class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

digitsOnly({double? min, double? max, int? decimalDigits}) → TextInputFormatter
integerOnly({int? min, int? max}) → TextInputFormatter
mathExpression({Map<String, dynamic>? context}) → TextInputFormatter
time({required int length}) → TextInputFormatter