ImageProperties class

Constructors

ImageProperties({Rect cropRect = Rect.zero, double rotation = 0, bool flipHorizontal = false, bool flipVertical = false})
const

Properties

cropRect → Rect
final
flipHorizontal → bool
final
flipVertical → bool
final
hashCode → int
The hash code for this object.
no setteroverride
rotation → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ValueGetter<Rect>? cropRect, ValueGetter<double>? rotation, ValueGetter<bool>? flipHorizontal, ValueGetter<bool>? flipVertical}) → ImageProperties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override