InputClearFeature class

Inheritance

Constructors

InputClearFeature({InputFeatureVisibility visibility = InputFeatureVisibility.always, InputFeaturePosition position = InputFeaturePosition.trailing, Widget? icon})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
final
position → InputFeaturePosition
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visibility → InputFeatureVisibility
finalinherited

Methods

createState() → InputFeatureState<InputFeature>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited