NullableTimeOfDay class

Constructors

NullableTimeOfDay({int? hour, int? minute, int? second})

Properties

hashCode → int
The hash code for this object.
no setteroverride
hour → int?
final
minute → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → int?
final
toTimeOfDay → TimeOfDay?
no setter

Methods

copyWith({ValueGetter<int?>? hour, ValueGetter<int?>? minute, ValueGetter<int?>? second}) → NullableTimeOfDay
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<TimePart, int>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override
operator [](TimePart part) → int?

Static Methods

fromTimeOfDay(TimeOfDay? timeOfDay) → NullableTimeOfDay?