PhoneNumber class

Constructors

PhoneNumber(Country country, String number)
const

Properties

country → Country
final
fullNumber → String
no setter
hashCode → int
The hash code for this object.
no setteroverride
number → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override