SelectData class

Constructors

SelectData({required bool? autoClose, required Predicate<Object?> isSelected, required SelectValueChanged<Object?> onChanged, required bool hasSelection, required bool enabled})
const

Properties

autoClose → bool?
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setteroverride
hasSelection → bool
final
isSelected → Predicate<Object?>
final
onChanged → SelectValueChanged<Object?>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override