AbsoluteResizablePaneController class

Inheritance
Mixed-in types

Constructors

AbsoluteResizablePaneController(double _size, {bool collapsed = false})

Properties

collapsed bool
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
no getter
value double
The current value of the object.
no setteroverride

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
collapse() → void
override
computeSize(double paneSize, {double? minSize, double? maxSize}) double
override
dispose() → void
Discards any resources used by the object.
inherited
expand() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resize(double newSize, double paneSize, {double? minSize, double? maxSize}) → void
Resizes the controller by the given delta amount.
override
toString() String
A string representation of this object.
inherited
tryCollapse([PanelSibling direction = PanelSibling.both]) bool
inherited
tryExpand([PanelSibling direction = PanelSibling.both]) bool
inherited
tryExpandSize(double size, [PanelSibling direction = PanelSibling.both]) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited