StepProperties class

Constructors

StepProperties({required StepSize size, required List<Step> steps, required ValueListenable<StepperValue> state, required Axis direction})
const

Properties

direction → Axis
final
hasFailure → bool
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → StepSize
final
state → ValueListenable<StepperValue>
final
steps → List<Step>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override
operator [](int index) → Step?