TableTheme class

Constructors

TableTheme({Border? border, Color? backgroundColor, BorderRadiusGeometry? borderRadius, TableCellTheme? cellTheme})
const

Properties

backgroundColor → Color?
final
border → Border?
final
borderRadius → BorderRadiusGeometry?
final
cellTheme → TableCellTheme?
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Border? border, Color? backgroundColor, TableCellTheme? cellTheme}) → TableTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override