BranchLine class abstract

Implementers

Constructors

BranchLine()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, List<TreeNodeDepth> depth, int index) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

line → const IndentGuideLine
none → const IndentGuideNone
path → const IndentGuidePath