TreeItemExpandDefaultHandler<T> class

Constructors

TreeItemExpandDefaultHandler(List<TreeNode<T>> nodes, TreeNode<T> target, ValueChanged<List<TreeNode<T>>> onChanged)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nodes → List<TreeNode<T>>
final
onChanged → ValueChanged<List<TreeNode<T>>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → TreeNode<T>
final

Methods

call(bool expanded) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited