Window class

Constructors

Window({Widget? title, Widget? actions = const WindowActions(), Widget? content, bool resizable = true, bool draggable = true, bool closable = true, bool maximizable = true, bool minimizable = true, bool enableSnapping = true, required Rect? bounds, Rect? maximized, bool minimized = false, bool alwaysOnTop = false, BoxConstraints constraints = kDefaultWindowConstraints})
Window.controlled({Widget? title, Widget? actions = const WindowActions(), Widget? content, required WindowController? controller})

Properties

actions → Widget?
final
alwaysOnTop → bool?
final
bounds → Rect?
final
closable → bool?
final
closed → ValueNotifier<bool>
final
constraints → BoxConstraints?
final
content → Widget?
final
controller → WindowController?
final
draggable → bool?
final
enableSnapping → bool?
final
handle → WindowHandle
no setter
hashCode → int
The hash code for this object.
no setterinherited
maximizable → bool?
final
maximized → Rect?
final
minimizable → bool?
final
minimized → bool?
final
mounted → bool
no setter
resizable → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited