WindowController class

Inheritance

Constructors

WindowController({required Rect bounds, Rect? maximized, bool minimized = false, bool focused = false, bool closable = true, bool resizable = true, bool draggable = true, bool maximizable = true, bool minimizable = true, bool enableSnapping = true, BoxConstraints constraints = kDefaultWindowConstraints})

Properties

alwaysOnTop ↔ bool
getter/setter pair
attachedState → WindowHandle
no setter
bounds ↔ Rect
getter/setter pair
closable ↔ bool
getter/setter pair
constraints ↔ BoxConstraints
getter/setter pair
draggable ↔ bool
getter/setter pair
enableSnapping ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
maximizable ↔ bool
getter/setter pair
maximized ↔ Rect?
getter/setter pair
minimizable ↔ bool
getter/setter pair
minimized ↔ bool
getter/setter pair
mounted → bool
no setter
resizable ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ WindowState
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited