WindowState class

Constructors

WindowState({required Rect bounds, Rect? maximized, bool minimized = false, bool alwaysOnTop = false, bool closable = true, bool resizable = true, bool draggable = true, bool maximizable = true, bool minimizable = true, bool enableSnapping = true, BoxConstraints constraints = kDefaultWindowConstraints})
const

Properties

alwaysOnTop → bool
final
bounds → Rect
final
closable → bool
final
constraints → BoxConstraints
final
draggable → bool
final
enableSnapping → bool
final
hashCode → int
The hash code for this object.
no setteroverride
maximizable → bool
final
maximized → Rect?
final
minimizable → bool
final
minimized → bool
final
resizable → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Rect? bounds, bool? minimized, bool? alwaysOnTop, bool? closable, bool? resizable, bool? draggable, bool? maximizable, bool? minimizable, bool? enableSnapping, BoxConstraints? constraints}) → WindowState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
withMaximized(Rect? maximized) → WindowState

Operators

operator ==(Object other) → bool
The equality operator.
override