OverlayHandlerStateMixin<T extends StatefulWidget> mixin

Superclass constraints
Mixin applications
Available extensions

Properties

alignment AlignmentGeometry
no getter
allowInvertHorizontal bool
no getter
allowInvertVertical bool
no getter
anchorAlignment AlignmentGeometry
no getter
anchorContext BuildContext
no getter
context BuildContext
The location in the tree where this widget builds.
no setterinherited
follow bool
no getter
hashCode int
The hash code for this object.
no setterinherited
heightConstraint PopoverConstraint
no getter
margin EdgeInsets
no getter
mounted bool
Whether this State object is currently in a tree.
no setterinherited
offset Offset?
no getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget → T
The current configuration.
no setterinherited
widthConstraint PopoverConstraint
no getter

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
changeModel<T>(Symbol key, T value) → void

Available on State<X>, provided by the StateExtension extension

Change the data of the model with the given key. Throws an assertion error if the model is read-only.
close([bool immediate = false]) Future<void>
closeLater() → void
closeWithResult<X>([X? value]) Future<void>
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
find<T>() → T

Available on State<X>, provided by the StateExtension extension

Find the data of the given type from the context. Does not listen to the data changes.
findMessenger<T>() → T

Available on State<X>, provided by the StateExtension extension

Find the stored data somewhere in the ancestor DataMessenger descendants. Throws an assertion error if the data is not found.
findModel<T>(Symbol key) → T

Available on State<X>, provided by the StateExtension extension

Find the data of the given type from the context. Throws an assertion error if the data is not found.
findProperty<T>(Symbol key) ModelProperty<T>

Available on State<X>, provided by the StateExtension extension

Find the property of the given type from the context. Throws an assertion error if the data is not found.
findRoot<T>() → T

Available on State<X>, provided by the StateExtension extension

Find the root data of the given type from the context. Throws an assertion error if the data is not found.
initState() → void
Called when this object is inserted into the tree.
inherited
maybeChangeModel<T>(Symbol key, T value) → void

Available on State<X>, provided by the StateExtension extension

Optionally change the data of the model with the given key. Ignores if the model is read-only.
maybeFind<T>() → T?

Available on State<X>, provided by the StateExtension extension

Optionally find the data of the given type from the context.
maybeFindMessenger<T>() → T?

Available on State<X>, provided by the StateExtension extension

Find the DataMessenger that holds all of the data with the given type from the context.
maybeFindModel<T>(Symbol key) → T?

Available on State<X>, provided by the StateExtension extension

Optionally find the data of the given type from the context. Returns null if the data is not found.
maybeFindProperty<T>(Symbol key) ModelProperty<T>?

Available on State<X>, provided by the StateExtension extension

Optionally find the property of the given type from the context. Returns null if the data is not found.
maybeFindRoot<T>() → T?

Available on State<X>, provided by the StateExtension extension

Optionally find the root data of the given type from the context.
maybeModel<T>(Symbol key) → T?

Available on State<X>, provided by the StateExtension extension

Optionally find the data of the given type from the context. Returns null if the data is not found.
maybeOf<T>() → T?

Available on State<X>, provided by the StateExtension extension

Optionally find and listen to data changes of the data with the given type from the context.
maybeProperty<T>(Symbol key) ModelProperty<T>?

Available on State<X>, provided by the StateExtension extension

Optionally find and listen to property changes of the data with the given type from the context. Returns null if the data is not found.
model<T>(Symbol key) → T

Available on State<X>, provided by the StateExtension extension

Find the data of the given type from the context. Throws an assertion error if the data is not found.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
of<T>() → T

Available on State<X>, provided by the StateExtension extension

Find and listen to data changes of the data with the given type from the context.
property<T>(Symbol key) ModelProperty<T>

Available on State<X>, provided by the StateExtension extension

Find and listen to property changes of the data with the given type from the context. Throws an assertion error if the data is not found.
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited