ResizableItem class

Constructors

ResizableItem({required double value, double min = 0, double max = double.infinity, bool collapsed = false, double? collapsedSize, bool resizable = true})

Properties

collapsed → bool
final
collapsedSize → double?
final
hashCode → int
The hash code for this object.
no setterinherited
max → double
final
min → double
final
newCollapsed → bool
no setter
newValue → double
no setter
resizable → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited