Resizer class

Constructors

Resizer(List<ResizableItem> items, {double collapseRatio = 0.5, double expandRatio = 0.5})

Properties

collapseRatio → double
final
expandRatio → double
final
hashCode → int
The hash code for this object.
no setterinherited
items → List<ResizableItem>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

attemptCollapse(int index, int direction) → bool
attemptExpand(int index, int direction, double delta) → bool
attemptExpandCollapsed(int index, int direction) → bool
dragDivider(int index, double delta) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited