ResizablePaneController class

Inheritance

Constructors

ResizablePaneController(double size, {bool collapsed = false})

Properties

collapsed bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
getter/setter pair
value ResizablePaneValue
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited
tryCollapse([PanelSibling direction = PanelSibling.both]) bool
tryExpand([PanelSibling direction = PanelSibling.both]) bool
tryExpandSize(double size, [PanelSibling direction = PanelSibling.both]) bool
trySetSize(double newSize, [PanelSibling direction = PanelSibling.both]) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited