DataHolder<T> class abstract

Constructors

DataHolder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findData(BuildContext context, Type type) → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(ForwardableDataState<T> receiver) → void
toString() String
A string representation of this object.
inherited
unregister(ForwardableDataState<T> receiver) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited