SingleChartColorScheme class

Implemented types

Constructors

SingleChartColorScheme(Color color)
const

Properties

chart1 Color
no setteroverride
chart2 Color
no setteroverride
chart3 Color
no setteroverride
chart4 Color
no setteroverride
chart5 Color
no setteroverride
chartColors List<Color>
no setteroverride
color Color
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited