ContrastedColorScheme class

Constructors

ContrastedColorScheme({required ColorScheme light, required ColorScheme dark})
const

Properties

dark ColorScheme
final
hashCode int
The hash code for this object.
no setterinherited
light ColorScheme
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scheme(Brightness brightness) ColorScheme
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited