IceShaderSurfaceEffect class

Inheritance

Constructors

IceShaderSurfaceEffect({double spread = 2})
const

Properties

cachedFilter → Future<ImageFilter>
no setterinherited
calcRadius → double
no setteroverride
compatible → bool
no setterinherited
filter → Future<ImageFilter>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
program → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spread → double
final

Methods

buildCustom(BuildContext context, Widget child) → Widget
inherited
buildShader(FragmentProgram program) → FragmentShader
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited