ArcaneBarriers class

Constructors

ArcaneBarriers({Color barrierColor = Colors.black, double barrierOpacity = 0.3, Color? dialogBarrierColor, double? dialogBarrierOpacity, Color? menuBarrierColor, double? menuBarrierOpacity})
const

Properties

barrierColor → Color
final
barrierOpacity → double
final
dialog → Color
no setter
dialogBarrierColor → Color?
final
dialogBarrierOpacity → double?
final
hashCode → int
The hash code for this object.
no setterinherited
no setter
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited