EdgeTheme class

Constructors

EdgeTheme({double blurIntensity = 0.15, double blurAddedIntensity = 0.15, int blurCount = 5, double size = 28, bool autoEdge = false})
const

Properties

autoEdge → bool
final
blurAddedIntensity → double
final
blurCount → int
final
blurIntensity → double
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited