ArcaneTableMdx class

Inheritance
  • Object
  • MarkdownComponent
  • BlockMd
  • ArcaneTableMdx

Constructors

ArcaneTableMdx()

Properties

exp → RegExp
no setterinherited
expString → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inline → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → Set<MarkdownScope>
The nesting contexts this component is allowed to render in.
no setterinherited

Methods

build(BuildContext context, String text, GptMarkdownConfig config) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
span(BuildContext context, String text, GptMarkdownConfig config) → InlineSpan
inherited
test() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited