ArcaneHaptics class

Constructors

ArcaneHaptics({bool enabled = true, HapticsType? viewChangeType = HapticsType.medium, HapticsType? actionType = HapticsType.heavy, HapticsType? selectType = HapticsType.light, HapticsType? buttonType = HapticsType.medium})
const

Properties

actionType → HapticsType?
final
buttonType → HapticsType?
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectType → HapticsType?
final
viewChangeType → HapticsType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited