ArcaneLiquidGlass class

Constructors

ArcaneLiquidGlass({LiquidShape? shape, bool glassContainsChild = false, Clip clipBehavior = Clip.hardEdge, LiquidGlassSettings? settings = const LiquidGlassSettings(glassColor: Color.fromARGB(0, 0, 0, 0), thickness: 20, saturation: 1, lightness: 1, refractiveIndex: 1.61, chromaticAberration: 0, blend: 20, blur: 8, lightAngle: 0, lightIntensity: 0, ambientStrength: 0)})
const

Properties

clipBehavior → Clip
The clip behavior of this glass.
final
glassContainsChild → bool
Whether this glass should be rendered "inside" of the glass, or on top.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → LiquidGlassSettings?
final
shape → LiquidShape?
The shape of this glass.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited