MapNotifier<K, V> class
A map that can be listened to for changes and notifies listeners when the map changes.
- Inheritance
-
- Object
- Listenable
- ValueListenable<
Map< K, V> > - MapListenable<
K, V> - MapNotifier
- Implemented types
-
- Map<
K, V>
- Map<
- Mixed-in types
- Available extensions
Constructors
-
MapNotifier([Map<
K, V> map = const {}]) - Creates a map notifier.
Properties
-
entries
→ Iterable<
MapEntry< K, V> > -
The map entries of this Map.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether the object has listeners.
no setterinherited
- isEmpty → bool
-
Whether there is no key/value pair in the map.
no setteroverride
- isNotEmpty → bool
-
Whether there is at least one key/value pair in the map.
no setteroverride
-
keys
→ Iterable<
K> -
The keys of this Map.
no setteroverride
- length → int
-
The number of key/value pairs in the map.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ Map<
K, V> -
The current value of the object. When the value changes, the callbacks
registered with addListener will be invoked.
no setteroverride
-
values
→ Iterable<
V> -
The values of this Map.
no setteroverride
Methods
-
addAll(
Map< K, V> other) → void -
Adds all key/value pairs of
otherto this map.override -
addChangeListener(
MapChangeListener< K, V> listener) → void -
Adds a
listenerto be notified of changes.override -
addEntries(
Iterable< MapEntry< newEntries) → voidK, V> > -
Adds all key/value pairs of
newEntriesto this map.override -
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
override
-
cast<
RK, RV> () → Map< RK, RV> -
Provides a view of this map as having
RKkeys andRVinstances, if necessary.override -
clear(
) → void -
Removes all entries from the map.
override
-
compute(
K key, V compute(K key, V? value)) → V -
computeAsync(
K key, Future< V> compute(K key, V? value)) → Future<V> -
computeIfAbsent(
K key, V ifAbsent(K key)) → V -
computeIfAbsentAsync(
K key, Future< V> ifAbsent(K key)) → Future<V> -
computeIfPresent(
K key, V ifPresent(K key, V value)) → V -
computeIfPresentAsync(
K key, Future< V> ifPresent(K key, V value)) → Future<V> -
containsKey(
Object? key) → bool -
Whether this map contains the given
key.override -
containsValue(
Object? value) → bool -
Whether this map contains the given
value.override -
defaultAddListener(
ChangeListener listener) → void -
Add a listener to the list of listeners.
inherited
-
defaultNotifyListeners(
Object? event) → void -
Notify all the listeners.
inherited
-
defaultRemoveListener(
ChangeListener listener) → void -
Remove a listener from the list of listeners.
inherited
-
dispose(
) → void -
Disposes the object making it unusable for further operations and
releasing the resources.
inherited
-
firstKeyWhere(
bool test(V)) → K? -
firstValueWhere(
bool test(K)) → V? -
flip(
) → Map< V, List< K> > -
flipFlat(
) → Map< V, K> -
forEach(
void action(K key, V value)) → void -
Applies
actionto each key/value pair of the map.override -
keysWhere(
bool test(V)) → Iterable< K> -
map<
K2, V2> (MapEntry< K2, V2> convert(K key, V value)) → Map<K2, V2> -
Returns a new map where all entries of this map are transformed by
the given
convertfunction.override -
merge(
Map< K, V> other) → Map<K, V> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
MapChangeDetails< K, V> details) → void - Notifies listeners of the changes.
-
putIfAbsent(
K key, V ifAbsent()) → V -
Look up the value of
key, or add a new entry if it isn't there.override -
remap(
(K, V)? remapper(MapEntry< K, V> )) → Map<K, V> -
remove(
Object? key) → V? -
Removes
keyand its associated value, if present, from the map.override -
removeChangeListener(
MapChangeListener< K, V> listener) → void -
Removes a
listenerfrom being notified of changes.override -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
override
-
removeWhere(
bool test(K key, V value)) → void -
Removes all entries of this map that satisfy the given
test.override -
sortedKeysByValue(
int compare(V, V)?) → List< K> -
sortedValuesByKey(
int compare(K, K)?) → List< V> -
toString(
) → String -
A string representation of this object.
override
-
update(
K key, V update(V value), {V ifAbsent()?}) → V -
Updates the value for the provided
key.override -
updateAll(
V update(K key, V value)) → void -
Updates all values.
override
-
valuesWhere(
bool test(K)) → Iterable< V> -
where(
bool test(K key, V value)) → Map< K, V>
Operators
-
operator +(
Map< K, V> other) → Map<K, V> -
operator -(
K k) → Map< K, V> -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Object? key) → V? -
The value for the given
key, ornullifkeyis not in the map.override -
operator []=(
K key, V value) → void -
Associates the
keywith the givenvalue.override