change<T> static method
Change the data of the model with the given key. Throws an assertion error if the model is read-only.
TThe type of the data.contextThe build context.keyThe data key.dataThe new data.
Implementation
static void change<T>(BuildContext context, Symbol key, T data) {
final property = findProperty<T>(context, key);
property.value = data;
}