rebuildChildren property
Whether to rebuild the children when the value changes.
When true, changing the value will trigger a rebuild of the widget and its descendants. When false (the default), only widgets that explicitly listen to the stream will rebuild.
Implementation
final bool rebuildChildren;