SkeletonTheme constructor
const
SkeletonTheme({})
Creates a SkeletonTheme.
All parameters are optional and can be null to use intelligent defaults that integrate with the current theme's color scheme and design system.
Example:
const SkeletonTheme(
duration: Duration(milliseconds: 800),
fromColor: Colors.grey.withOpacity(0.1),
toColor: Colors.grey.withOpacity(0.2),
enableSwitchAnimation: true,
);
Implementation
const SkeletonTheme({
this.duration,
this.fromColor,
this.toColor,
this.enableSwitchAnimation,
});