URLValidator class

Inheritance

Constructors

URLValidator({String? message})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

combine(Validator<String> other) → Validator<String>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRevalidate(FormKey source) → bool
inherited
toString() → String
A string representation of this object.
inherited
validate(BuildContext context, String? value, FormValidationMode state) → FutureOr<ValidationResult?>
override

Operators

operator &(Validator<String> other) → Validator<String>
inherited
operator +(Validator<String> other) → Validator<String>
inherited
operator ==(Object other) → bool
The equality operator.
override
operator unary-() → Validator<String>
inherited
operator |(Validator<String> other) → Validator<String>
inherited
operator ~() → Validator<String>
inherited