child property
The widget to show or hide based on expansion state.
This can be any widget content including text, images, forms, or complex layouts. The child is completely removed from the layout when collapsed.
Implementation
final Widget child;
The widget to show or hide based on expansion state.
This can be any widget content including text, images, forms, or complex layouts. The child is completely removed from the layout when collapsed.
final Widget child;