child property
The main content widget displayed in the content area.
Type: Widget. This widget fills the content area above the tab bar
and typically shows content related to the currently focused tab.
Implementation
final Widget child;
The main content widget displayed in the content area.
Type: Widget. This widget fills the content area above the tab bar
and typically shows content related to the currently focused tab.
final Widget child;