TabPaneItemBuilder<T> typedef
TabPaneItemBuilder<T> =
TabChild Function(BuildContext context, TabPaneData<T> item, int index)
Builder function for creating tab child widgets from tab pane data.
Takes the build context, tab data, and index to create a TabChild widget that represents the visual appearance of each tab button.
Parameters:
context(BuildContext): Build context for theme accessitem(TabPaneDataindex(int): Zero-based index of this tab in the list
Returns: A TabChild widget for the tab button
Implementation
typedef TabPaneItemBuilder<T> = TabChild Function(
BuildContext context, TabPaneData<T> item, int index);