IconThemeProperties class

Constructors

IconThemeProperties({IconThemeData x4Small = const IconThemeData(size: 6), IconThemeData x3Small = const IconThemeData(size: 8), IconThemeData x2Small = const IconThemeData(size: 10), IconThemeData xSmall = const IconThemeData(size: 12), IconThemeData small = const IconThemeData(size: 16), IconThemeData medium = const IconThemeData(size: 20), IconThemeData large = const IconThemeData(size: 24), IconThemeData xLarge = const IconThemeData(size: 32), IconThemeData x2Large = const IconThemeData(size: 40), IconThemeData x3Large = const IconThemeData(size: 48), IconThemeData x4Large = const IconThemeData(size: 56)})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
large → IconThemeData
final
medium → IconThemeData
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
small → IconThemeData
final
x2Large → IconThemeData
final
x2Small → IconThemeData
final
x3Large → IconThemeData
final
x3Small → IconThemeData
final
x4Large → IconThemeData
final
x4Small → IconThemeData
final
xLarge → IconThemeData
final
xSmall → IconThemeData
final

Methods

copyWith({IconThemeData? x4Small, IconThemeData? x3Small, IconThemeData? x2Small, IconThemeData? xSmall, IconThemeData? small, IconThemeData? medium, IconThemeData? large, IconThemeData? xLarge, IconThemeData? x2Large, IconThemeData? x3Large, IconThemeData? x4Large}) → IconThemeProperties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scale(double factor) → IconThemeProperties
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override