CarouselController class
- Inheritance
-
- Object
- Listenable
- CarouselController
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldAnimate → bool
-
no setter
- value → double
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
override
-
animateNext(
Duration duration, [Curve curve = Curves.easeInOut]) → void -
animatePrevious(
Duration duration, [Curve curve = Curves.easeInOut]) → void -
animateSnap(
Duration duration, [Curve curve = Curves.easeInOut]) → void -
animateTo(
double value, Duration duration, [Curve curve = Curves.linear]) → void -
dispose(
) → void -
getCurrentIndex(
int? itemCount) → double -
jumpTo(
double value) → void -
next(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
previous(
) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
override
-
snap(
) → void -
tick(
Duration delta) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited