SafePasswordValidator class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
final
- requireDigit → bool
-
final
- requireLowercase → bool
-
final
- requireSpecialChar → bool
-
final
- requireUppercase → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
combine(
Validator< String> other) → Validator<String> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRevalidate(
FormKey source) → bool -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
BuildContext context, String? value, FormValidationMode state) → Future< ValidationResult?> -
override
Operators
-
operator &(
Validator< String> other) → Validator<String> -
inherited
-
operator +(
Validator< String> other) → Validator<String> -
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator |(
Validator< String> other) → Validator<String> -
inherited
-
operator ~(
) → Validator< String> -
inherited