Colors class
Constructors
- Colors()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- amber → const ColorShades
- black → const Color
- blue → const ColorShades
- cyan → const ColorShades
- emerald → const ColorShades
- fuchsia → const ColorShades
- gray → const ColorShades
- green → const ColorShades
- indigo → const ColorShades
- lime → const ColorShades
- neutral → const ColorShades
- orange → const ColorShades
- pink → const ColorShades
- purple → const ColorShades
- red → const ColorShades
- rose → const ColorShades
- sky → const ColorShades
- slate → const ColorShades
- stone → const ColorShades
- teal → const ColorShades
- transparent → const Color
- violet → const ColorShades
- white → const Color
- yellow → const ColorShades
- zinc → const ColorShades