Arcane class

Constructors

Arcane()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

$app ↔ ArcaneAppState?
getter/setter pair
app → ArcaneAppState
no setter
globalTheme → ArcaneTheme
no setter

Static Methods

closeDrawer(BuildContext context) → void
closeMenus(BuildContext context) → void
haptic(HapticsType? type, {bool force = false}) → Future<bool>
hapticAction() → Future<bool>
hapticButton() → Future<bool>
hapticSelect() → Future<bool>
hapticViewChange() → Future<bool>
pop<T extends Object?>(BuildContext context, [T? result]) → void
push<T extends Object?>(BuildContext context, Widget child) → Future<T?>
pushAndRemoveUntil<T extends Object?>(BuildContext context, Widget child, RoutePredicate predicate) → Future<T?>
pushReplacement<T extends Object?, TO extends Object?>(BuildContext context, Widget child) → Future<T?>
registerInitializer(String name, Future<void> run()) → Future<void>
themeOf(BuildContext context) → ArcaneTheme